@@ -112,7 +112,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
 
         match data_type {
             Some(dt) => quote! {
-                struct #state_name {
+                pub struct #state_name {
                     data: #dt
                 }
 
@@ -123,13 +123,13 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
                         }
                     }
 
-                    fn data(&self) -> &#dt {
+                    pub fn data(&self) -> &#dt {
                         &self.data
                     }
                 }
             },
             None => quote! {
-                struct #state_name {}
+                pub struct #state_name {}
 
                 impl #state_name {
                     fn new() -> Self {
@@ -151,7 +151,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
                 Some(a) => match shared_data_type {
                     Some(_) => quote! {
                         impl<T: Observer> #parent_name<#state_name, T> {
-                            fn #event(self, data: #a) -> Result<#parent_name<#next_state_name, T>, ()> {
+                            pub fn #event(self, data: #a) -> Result<#parent_name<#next_state_name, T>, ()> {
                                 self.observer.on_transition(stringify!(#state_name), stringify!(#next_state_name), Some(data))?;
                                 Ok(#parent_name::<#next_state_name, T>::new(#next_state_name::new(data), self.data, self.observer))
                             }
@@ -159,7 +159,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
                     },
                     None => quote! {
                         impl<T: Observer> #parent_name<#state_name, T> {
-                            fn #event(self, data: #a) -> Result<#parent_name<#next_state_name, T>, ()> {
+                            pub fn #event(self, data: #a) -> Result<#parent_name<#next_state_name, T>, ()> {
                                 self.observer.on_transition(stringify!(#state_name), stringify!(#next_state_name), Some(data))?;
                                 Ok(#parent_name::<#next_state_name, T>::new(#next_state_name::new(data), self.observer))
                             }
@@ -169,7 +169,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
                 None => match shared_data_type {
                     Some(_) => quote! {
                         impl<T: Observer> #parent_name<#state_name, T> {
-                            fn #event(self) -> Result<#parent_name<#next_state_name, T>, ()> {
+                            pub fn #event(self) -> Result<#parent_name<#next_state_name, T>, ()> {
                                 self.observer.on_transition(stringify!(#state_name), stringify!(#next_state_name), Option::<()>::None)?;
                                 Ok(#parent_name::<#next_state_name, T>::new(#next_state_name::new(), self.data, self.observer))
                             }
@@ -177,7 +177,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
                     },
                     None => quote! {
                         impl<T: Observer> #parent_name<#state_name, T> {
-                            fn #event(self) -> Result<#parent_name<#next_state_name, T>, ()> {
+                            pub fn #event(self) -> Result<#parent_name<#next_state_name, T>, ()> {
                                 self.observer.on_transition(stringify!(#state_name), stringify!(#next_state_name), Option::<()>::None)?;
                                 Ok(#parent_name::<#next_state_name, T>::new(#next_state_name::new(), self.observer))
                             }
@@ -208,7 +208,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
                             }
                         }
 
-                        fn data(&self) -> &#sdt {
+                        pub fn data(&self) -> &#sdt {
                             &self.data
                         }
                     }
@@ -283,15 +283,15 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
 
     let parent_struct = match shared_data_type {
         Some(sdt) => quote! {
-            struct #parent_name<T, U: Observer> {
-                state: T,
+            pub struct #parent_name<T, U: Observer> {
+                pub state: T,
                 data: #sdt,
                 observer: U
             }
         },
         None => quote! {
-            struct #parent_name<T, U: Observer> {
-                state: T,
+            pub struct #parent_name<T, U: Observer> {
+                pub state: T,
                 observer: U
             }
         }
@@ -382,7 +382,7 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
     });
 
     let out = quote! {
-        trait Observer {
+        pub trait Observer {
             fn on_init<T: Serialize, U: Serialize>(&self, to: &str, data: Option<T>, state_data: Option<U>) -> Result<(), ()> {
                 println!("initializing to {}", to);
 
@@ -401,11 +401,11 @@ pub fn statemachine(input: TokenStream) -> TokenStream {
         #(#parent_state_impls)*
         #transitions_block
 
-        enum #wrapped_type<T: Observer> {
+        pub enum #wrapped_type<T: Observer> {
             #(#state_names(#parent_name<#state_names, T>)),*
         }
 
-        enum Encoded {
+        pub enum Encoded {
             Json(String)
         }
 
